@@ -57,7 +57,7 @@ def wf_bandstructure2D(structure, c=None):
     mpr2d = MPRelaxSet2D(structure, force_gamma=True)
     '''check bandstructure.yaml'''
     wf = get_wf(structure, "bandstructure.yaml", vis=MPRelaxSet2D(structure, force_gamma=True), \
-                params=[{'vasp_input_set': mpr2d},{},{},{}], common_params={"vasp_cmd": vasp_cmd, "db_file": db_file, "vdw_kernel_dir": vdw_kernel})
+                params=[{'vasp_input_set': mpr2d},{},{},{}], common_params={"vasp_cmd": vasp_cmd, "db_file": db_file,}) #"vdw_kernel_dir": vdw_kernel})
 
     wf = add_common_powerups(wf, c)
 
